.. _api:

API - PoundPay Client Library
=============================

.. automodule:: poundpay
   :members:
   :inherited-members:

.. autofunction:: configure


Payment Exceptions
``````````````````

.. autoclass:: poundpay.payments.PaymentEscrowError

.. autoclass:: poundpay.payments.PaymentReleaseError

.. autoclass:: poundpay.payments.PaymentCancelError

